#
# spec file for package python-libusb1
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-libusb1
Version:        3.0.0
Release:        1.7
Summary:        Python wrapper for libusb-1.0
# Relicensed from GPL to LGPLv2.1+ in May 2015
# https://github.com/vpelletier/python-libusb1/commit/238eaefa0759622afc554884b4b333d9bf946c65
License:        LGPL-2.1-or-later
URL:            https://github.com/vpelletier/%{name}
Source:         https://files.pythonhosted.org/packages/source/l/libusb1/libusb1-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  libusb-1_0-0
BuildRequires:  python-rpm-macros
Requires:       libusb-1_0-0
BuildArch:      noarch
%python_subpackages

%description
This is a pure python wrapper for libusb-1.0.

%prep
%setup -q -n libusb1-%{version}
sed -i '/wheel/d' setup.py

sed -i '1{/^#!/d}' examples/*.py
chmod a-x examples/*.py

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%python_exec -m usb1.testUSB1 -v

%files %{python_files}
%doc README.rst examples/
%license COPYING.LESSER
%{python_sitelib}/*

%changelog
* Thu Mar  3 2022 Steve Kowalik <steven.kowalik@suse.com>
- Update to 3.0.0:
  * Add support for pyinstaller.
  * Fix support for python 3.10.
  * Drop python <3.4 support.
  * Do not load the C library on import. Allows applications to customise
    the lookup logic (see usb1.loadLibrary).
  * Add LIBUSB_SPEED_SUPER_PLUS.
  * Better control device iterator end of life.
  * Fix objects escaping control from their parent.
  * Fix a TypeError exception in USBContext.handleEvents.
  * Fix an AttributeError exception in USBContext.hotplugRegisterCallback.
  * Fix segfault in pypy3 when finalizing USBDevice objects.
  * Source only: convert examples to python3.
  * Release process: also run some examples scripts.
  * Update versioneer to be compatible with 3.11.
  * Drop python <3.6 support.
* Wed Jan 20 2021 John Vandenberg <jayvdb@gmail.com>
- Update to v1.9.1
  * Fix installation from pypi source tarball, broken in 1.8.1
- from v1.9
  * Drop USBPollerThread
  * Deprecate libusb-lock-related USBContext API
- from v1.8.1
  * Embed libusb1 dll for easier deployment on Windows
  * Cryptographically signed releases
  * Use libusb_free_pollfds whenever available (libusb1>=1.0.20)
  * Fix hotplug callback destruction at context teardown
  * Drop remnants of python 2.6 support code
- from v1.8
  * Fix getExtra and libusb1.libusb_control_transfer_get_data
  * Fix getMaxPower unit on SuperSpeed devices
* Wed May 15 2019 Jonathan Harker <jharker@suse.com>
- Upgrade to 1.7.1:
  * usb1.__version__ is now present, managed by versioneer. Fix an occasional
    segfault when closing a transfer from inside its callback function.
* Mon Apr 15 2019 John Vandenberg <jayvdb@gmail.com>
- Activate test suite
- Remove unnecessary build dependencies, and add BuildArch: noarch
- Remove GPL license as it was relicensed to LGPL2.1+ in May 2015
* Fri Dec 14 2018 marec@detebe.org
- Update to version 1.7:
  * Bump to 1.7 .
  * setup: Simplify.
  * Bump copyright year.
  * usb1: Expose transferred byte count and received bytes on synchronous API
  * usb1: Fix docstring interruptRead refering to itself.
  * Specify that it is compatible with python 3 in setup.py
  * README: libusb.org seems dead, switch to the fork.
  * usb1: Move getManufacturer, getProduct ,getSerialNumber to USBDeviceHandle.
  * usb1: get{,ASCII}StringDescriptor now return None for descriptor 0.
  * Bump to 1.6.6 .
* Mon Aug 27 2018 marec@detebe.org
- Update to version 1.6.6:
  * Bump to 1.6.6 .
  * usb1: Expose string descriptors on USBDevice.
  * Bump to 1.6.5 .
  * usb1: Bind "cast" to USBContext class.
  * Cast libusb pollfd callbacks from null pointer to proper type.
  * examples: Make hotplug and listdev examples python3-friendly.
  * setup.py: Tell setuptools to run 2to3 when running on python3
  * usb1: Document hotplug handler limitations.
  * Bump to 1.6.4 .
  * usb1: Fix asynchronous control transfer buffer.
* Tue Jul 24 2018 marec@detebe.org
- Update to version 1.6.5:
  * Bump to 1.6.5 .
  * usb1: Bind "cast" to USBContext class.
  * Cast libusb pollfd callbacks from null pointer to proper type.
  * examples: Make hotplug and listdev examples python3-friendly.
  * setup.py: Tell setuptools to run 2to3 when running on python3
  * usb1: Document hotplug handler limitations.
  * Bump to 1.6.4 .
  * usb1: Fix asynchronous control transfer buffer.
  * Bump to 1.6.3 .
  * Deprecate USBPollerThread.
* Thu Jun 21 2018 marec@detebe.org
- initial package build
